@@ -13,9 +13,12 @@ else if (niter==-12) errormessage <- "Result may not provide the true optimum"
 else if (niter==-13) errormessage <- "Result may be inaccurate in view of a point"
 else if (niter==-14) errormessage <- "Result may be inaccurate in view of a function value"
 
-if(niter>0) cat("\n Log MLE at observations: \n", (x$logMLE),
-    "\n\n Number of Iterations: ",x$NumberOfEvaluations[1],
-    "\n\n Number of Function Evaluations: ",x$NumberOfEvaluations[2],
-    fill=10)
-else cat("SolvOpt error: ",errormessage, "\n")
+if (niter > 0)
+  {cat("\n Log MLE at observations: \n");
+   print(x$logMLE);
+   cat( "\n Number of Iterations: ",x$NumberOfEvaluations[1],"\n\n Number of Function Evaluations: ",x$NumberOfEvaluations[2],"\n")
+ }
+else cat("SolvOpt error: ", errormessage, "\n")
 }
+
+
